@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 # A copy of the license can be found in a file named "licence.txt", at the
 # root directory of this project.
@@ -55,7 +55,7 @@ END {
 @Perlilog::ISA = (Exporter);
 @Perlilog::EXPORT = qw[&init &override &underride &inherit &inheritdir &interface &interfaceclass
 		       &constreset &definedclass &globalobj &execute];
-$Perlilog::VERSION = '0.3';
+$Perlilog::VERSION = '1.0';
 $Perlilog::STARTTIME = localtime();
 
 $Perlilog::perlilogflag = 0;
@@ -501,8 +501,7 @@ Perlilog - Verilog environment and IP core handling in Perl
 
 =head1 DESCRIPTION
 
-The project is extensively documented in Perlilog's user guide, which can be downloaded at the project's
-home page, L<http://www.opencores.org/perlilog/>, or at my own:  L<http://www.billauer.co.il/perlilog.html>.
+The project is extensively documented in Perlilog's user guide, which can be downloaded at L<http://www.billauer.co.il/perlilog.html>.
 
 In wide terms, Perlilog is a Perl environment for Verilog code manipulation. It supplies the Perl programmer
 with several strong tools for managing Perl modules and connecting between them.
@@ -531,20 +530,13 @@ Automatic generation of bridges when needed to interface between different bus p
 
 =back
 
-=head1 ACKNOWLEDGEMENTS
-
-This project would not exist without the warm support of Flextronics Semiconductors in Israel,
-and Dan Gunders in particular.
-
 =head1 AUTHOR
 
-Eli Billauer, E<lt>elib@flextronics.co.ilE<gt>
+Eli Billauer, E<lt>eli.billauer@gmail.comE<gt>
 
 =head1 SEE ALSO
 
-The Perlilog project's home page: L<http://www.opencores.org/perlilog/>
-
-The author's home page: L<http://www.billauer.co.il/>
+The Perlilog project's home page: L<http://www.billauer.co.il/perlilog.html>
 
 The Eobj project: L<http://www.billauer.co.il/eobj.html>
 
